@@ -23,7 +23,7 @@
 #' data(ecoli_core)
 #' ecoli_core_with_flux <- find_fluxes_df(ecoli_core)
 #' }
-find_fluxes_df <- function(reaction_table, do_minimization=TRUE){
+find_fluxes_df <- function(reaction_table, do_minimization=FALSE){
   mod1 <- reaction_table %>%
     reactiontbl_to_expanded() %>%
     expanded_to_ROI()
